@@ -1,10 +1,10 @@
 from enum import Enum
 from typing import Union
-from karas.chain import MessageChain
-from karas.util import BaseModel
-from karas.Sender import Client, Friend, Group, Member, Operator, Stranger, Subject
+
+from karas.sender import Client, Friend, Group, Member, Operator, Subject
 from karas.messages import MessageBase, MessageEnum
 from karas.permission import Permission
+from karas.util import BaseModel
 
 __events__ = {
     "messageEvent":
@@ -79,6 +79,10 @@ class RequestEvent(EventBase):
     nick: str
     message: str
 
+    def __init__(self, *args, **kws):
+        super().__init__(args, kws)
+        self.operate = None
+
     @property
     def accept(self):
         self.operate = 0
@@ -187,6 +191,7 @@ class BotLeaveEventKick(GroupEventBase):
     """Bot被踢出一个群"""
     type: str = "BotLeaveEventKick"
     operator: Member
+    group: Group
 
     def __str__(self) -> str:
         return super().__str__() + f":{self.group}"
@@ -469,8 +474,6 @@ class CommandExecutedEvent(EventBase):
     args: dict
 
 
-
-
 class EventEnum(Enum):
     BotOnlineEvent: "BotOnlineEvent" = BotOnlineEvent
     BotOfflineEventActive: "BotOfflineEventActive" = BotOfflineEventActive
